# Processador-XML

Script que filtra arquivos .XML que definem uma NFE e extrai algumas informações gerando um
arquivo do tipo .xlsx (Excel).

### Informações extraidas

- Chave de Acesso da NFE
- Número da NFE
- Data da Emissão
- Nome do Fornecedor
- Valor Total da NFE
